.. snf-image-creator documentation master file, created by
   sphinx-quickstart on Mon Oct  8 12:34:17 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to snf-image-creator's documentation!
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

snf-image-creator is an image creation tool for `Synnefo <https://code.grnet.gr/projects/synnefo>`_

Contents:

.. toctree::
   :maxdepth: 2

   overview
   install
   usage

Contact
=======

For questions or bug reports you can contact the Synnefo team at the following
mailing lists:

 * Users list: synnefo@googlegroups.com
 * Developers list: synnefo-devel@googlegroups.com

..
 Indices and tables
 ==================
 * :ref:`genindex`
 * :ref:`modindex`
 * :ref:`search`

